@@ -45,8 +45,12 @@ class App:
 
     def wsgi(self, env, start_response):
         request = Request(env)
-        response = self(request)
-        body = response.start(request, start_response)
+        try:
+            response = self(request)
+            body = response.start(request, start_response)
+        except Exception as err:
+            print(err)
+            body = self.error(request, 500).start(request, start_response)
         return body
 
     def __call__(self, request):
