@@ -47,13 +47,11 @@ def resize_icon(icon):
         scale = 200 / width
     width *= scale
     height *= scale
-    print(width, height)
     resize = img.resize((int(width), int(height)), resample=Image.NEAREST)
     if width > height:
         cropped = resize.crop((int((width-height)/2), 0, width - int((width-height)/2), height))
     else:
         cropped = resize.crop((0, int((height-width)/2), width, height - int((height-width)/2)))
-    print(cropped.size, width, height, int((width-height)/2))
     export = io.BytesIO()
     cropped.save(export, format="PNG")
     return export.getvalue()
@@ -69,7 +67,7 @@ class SessionController(Controller):
                     form["password"]
                 )
                 sess = request.session()
-                sess["jwt_token"] = User.get_jwt(result)
+                sess["jwt_token"] = result.get_jwt()
                 redirect_to = request.query.get("redirect_to", ["/"])[0]
                 return Response.redirect(redirect_to)
             except Exception as err:
@@ -98,11 +96,14 @@ class RegisterController(Controller):
                 user.name = form["name"]
                 user.icon = resize_icon(form["icon"]) if form["icon"] is not None else user.icon
                 user.create()
+                print(user._id)
+                sess["jwt_token"] = user.get_jwt()
+                roles = invite.roles;
+                if len(roles) > 0:
+                    for role_screen_name in invite.roles.split(":"):
+                        role = Role.retrieve(screen_name = role_screen_name)
+                        role.append(user)
                 invite.delete()
-                for role_screen_name in invite.roles.split(":"):
-                    role = Role.retrieve(screen_name = role_screen_name)
-                    role.append(user)
-                sess["jwt_token"] = User.get_jwt(user)
                 return Response.redirect(self.app.convert_url("/"))
             except (ValidationError, ValueError) as err:
                 icon = form["icon"]
@@ -234,19 +235,19 @@ class HomeController(Controller):
                     role.screen_name = form['role_screen_name']
                     role.name = form['role_name'] if form['role_name'] is not None else form['role_screen_name']
                     role.create()
-                for role_screen_name, role_permissions in form['role'].items():
-                    role = Role.retrieve(screen_name = role_screen_name)
-                    role.permissions = [Permission.retrieve(screen_name=permission) for permission in role_permissions]
-                    role.update()
+                for permission_screen_name, permission_roles in form['permission'].items():
+                    permission = Permission.retrieve(screen_name = permission_screen_name)
+                    permission.roles = [Role.retrieve(screen_name=role) for role in permission_roles]
+                    permission.update()
                 if form["inner_role_screen_name"] is not None:
                     inner_role = InnerRole()
                     inner_role.screen_name = form['inner_role_screen_name']
                     inner_role.name = form['inner_role_name'] if form['inner_role_name'] is not None else form['inner_role_screen_name']
                     inner_role.create()
-                for inner_role_screen_name, inner_role_permissions in form['inner_role'].items():
-                    inner_role = InnerRole.retrieve(screen_name = inner_role_screen_name)
-                    inner_role.permissions = [InnerPermission.retrieve(screen_name=permission) for permission in inner_role_permissions]
-                    inner_role.update()
+                for inner_permission_screen_name, inner_permission_roles in form['inner_permission'].items():
+                    inner_permission = InnerPermission.retrieve(screen_name=inner_permission_screen_name)
+                    inner_permission.roles = [InnerRole.retrieve(screen_name=role) for role in inner_permission_roles]
+                    inner_permission.update()
                 with open(self.app.project_dir / "welcome_message.md", "w") as f:
                     f.write(welcome_message_)
                 error = "変更を保存しました"
@@ -343,20 +344,12 @@ class UsersController(Controller):
                 user.screen_name = form["screen_name"]
                 user.name = form["name"]
                 user.icon = resize_icon(form["icon"]) if form["icon"] is not None else user.icon
+                roles_ = []
                 for role in form["roles"]:
-                    user.roles.append(Role.retrieve(screen_name=role))
+                    roles_.append(Role.retrieve(screen_name=role))
+                user.roles = roles_
                 user.update()
-                return Response.render(
-                    template,
-                    {
-                        "message": "変更を保存しました",
-                        "user": user,
-                        "screen_name": user.screen_name,
-                        "name": user.name,
-                        "icon": user.icon,
-                        "roles": roles
-                    },
-                )
+                return Response.redirect(self.app.convert_url("/users/" + user.screen_name + "/settings"))
             except Exception as err:
                 error = str(err)
                 return Response.render(
