@@ -8,10 +8,10 @@ class SettingsForm(Form):
     welcome_message = Field(label="ウェルカムボード", required=True)
     role_name = Field(label='役割名')
     role_screen_name = Field(label='役割ID', regex=r'^([0-9a-zA-Z_-]+)$')
-    role = DictField(listed=True)
+    permission = DictField(listed=True)
     inner_role_name = Field(label='グループ役割名')
     inner_role_screen_name = Field(label='グループ役割ID', regex=r'^([0-9a-zA-Z_-]+)$')
-    inner_role = DictField(listed=True)
+    inner_permission = DictField(listed=True)
 
 class LoginForm(Form):
     screen_name = Field(label="ログイン名", required=True)
@@ -35,7 +35,7 @@ class InviteForm(Form):
 
 
 class UserUpdateForm(Form):
-    icon = FileField(label="プロフィール画像", initial=load_noimage_user())
+    icon = FileField(label="プロフィール画像")
     name = Field(label="名前", required=True)
     screen_name = Field(label="ログイン名")
     roles = Field(label="役割", listed=True)
@@ -49,7 +49,7 @@ class GroupCreateForm(Form):
 
 
 class GroupUpdateForm(Form):
-    icon = FileField(label="プロフィール画像", initial=load_noimage_group())
+    icon = FileField(label="プロフィール画像")
     name = Field(label="名前", required=True)
     screen_name = Field(label="ドメイン名", required=True)
     parent = Field(label="親グループ")
